@@ -24,7 +24,7 @@ use strict;
 use warnings;
 
 package RT::Client::REST;
-$RT::Client::REST::VERSION = '0.58';
+$RT::Client::REST::VERSION = '0.59';
 use Error qw(:try);
 use HTTP::Cookies;
 use HTTP::Request::Common;
@@ -721,6 +721,8 @@ sub basic_auth_cb {
     return $self->{_basic_auth_cb};
 }
 
+# Sometimes PodCoverageTests think LOGGER_METHODS is a vanilla sub
+
 use constant LOGGER_METHODS => (qw(debug warn info error));
 
 sub logger {
@@ -889,7 +891,7 @@ sub _version { $RT::Client::REST::VERSION }
     # The problem with the second approach is that it creates unrelated
     # methods in RT::Client::REST namespace.
     package RT::Client::REST::NoopLogger;
-$RT::Client::REST::NoopLogger::VERSION = '0.58';
+$RT::Client::REST::NoopLogger::VERSION = '0.59';
 sub new { bless \(my $logger), __PACKAGE__ }
     for my $method (RT::Client::REST::LOGGER_METHODS) {
         no strict 'refs'; ## no critic (ProhibitNoStrict)
@@ -911,7 +913,7 @@ RT::Client::REST - Client for RT using REST API
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
@@ -945,6 +947,8 @@ to implement some RT interactions from my application, but did not feel that
 invoking a shell command is appropriate.  Thus, I took B<rt> tool, written
 by Abhijit Menon-Sen, and converted it to an object-oriented Perl module.
 
+=for Pod::Coverage LOGGER_METHODS
+
 =head1 USAGE NOTES
 
 This API mimics that of 'rt'.  For a more OO-style APIs, please use
@@ -1353,4 +1357,60 @@ This software is copyright (c) 2020, 2018 by Dmitri Tikhonov.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Abhijit Menon-Sen belg4mit bobtfish Byron Ellacott Dean Hamstead dkrotkine Dmitri Tikhonov Marco Pessotto pplusdomain Sarvesh D Søren Lund Tom Harrison
+
+=over 4
+
+=item *
+
+Abhijit Menon-Sen <ams@wiw.org>
+
+=item *
+
+belg4mit <belg4mit>
+
+=item *
+
+bobtfish <bobtfish@bobtfish.net>
+
+=item *
+
+Byron Ellacott <code@bje.id.au>
+
+=item *
+
+Dean Hamstead <djzort@cpan.org>
+
+=item *
+
+dkrotkine <dkrotkine@gmail.com>
+
+=item *
+
+Dmitri Tikhonov <dmitri@cpan.org>
+
+=item *
+
+Marco Pessotto <melmothx@gmail.com>
+
+=item *
+
+pplusdomain <pplusdomain@gmail.com>
+
+=item *
+
+Sarvesh D <sarveshd@openmailbox.org>
+
+=item *
+
+Søren Lund <soren@lund.org>
+
+=item *
+
+Tom Harrison <tomh@apnic.net>
+
+=back
+
 =cut
